@@ -243,10 +243,10 @@ c        | overflow should not occur.                    |
 c        | REFERENCE: LAPACK subroutine zlahqr           |
 c        %-----------------------------------------------%
 c
-         unfl = pdlamch( 'safe minimum' )
+         unfl = pdlamch( comm, 'safe minimum' )
          ovfl = dble(one / unfl)
          call dlabad( unfl, ovfl )
-         ulp = dlamch( 'precision' )
+         ulp = pdlamch( comm, 'precision' )
          smlnum = unfl*( n / ulp )
          first = .false.
       end if
